==> kubernetes-model-kustomize-6.5.0-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/SelectorFluent.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface SelectorFluent<A extends SelectorFluent<A>> extends Fluent<A>{
  public String getAnnotationSelector();
  public A withAnnotationSelector(String annotationSelector);
  public Boolean hasAnnotationSelector();
  public String getGroup();
  public A withGroup(String group);
  public Boolean hasGroup();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public String getLabelSelector();
  public A withLabelSelector(String labelSelector);
  public Boolean hasLabelSelector();
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  public String getNamespace();
  public A withNamespace(String namespace);
  public Boolean hasNamespace();
  public String getVersion();
  public A withVersion(String version);
  public Boolean hasVersion();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}

==> kubernetes-model-kustomize-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/SelectorFluent.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface SelectorFluent<A extends SelectorFluent<A>> extends Fluent<A>{
  public String getAnnotationSelector();
  public A withAnnotationSelector(String annotationSelector);
  public Boolean hasAnnotationSelector();
  public String getGroup();
  public A withGroup(String group);
  public Boolean hasGroup();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public String getLabelSelector();
  public A withLabelSelector(String labelSelector);
  public Boolean hasLabelSelector();
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  public String getNamespace();
  public A withNamespace(String namespace);
  public Boolean hasNamespace();
  public String getVersion();
  public A withVersion(String version);
  public Boolean hasVersion();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}
